@@ -6,43 +6,7 @@ use Config;
 use base qw( Alien::Base );
 
 # ABSTRACT: Build and make available libffi
-our $VERSION = '0.14'; # VERSION
-
-sub libs
-{
-  my $class = shift;
-  
-  my $libs = $class->SUPER::libs(@_);
-
-  if($^O eq 'openbsd' && !$Config{usethreads} && Alien::FFI->install_type eq 'share')
-  {
-    $libs .= ' /usr/lib/libpthread.a';
-  }
-  
-  if($^O eq 'MSWin32' && $Config{ccname} eq 'cl')
-  {
-    $libs =~ s{-L}{/LIBPATH:}g;
-    $libs =~ s{-l([A-Za-z]+)}{$1.LIB}g;
-  }
-  
-  $libs;
-}
-
-sub cflags
-{
-  my $class = shift;
-  
-  my $cflags = $class->SUPER::cflags(@_);
-  
-  if($class->install_type eq 'share'
-  && $^O eq 'MSWin32'
-  && $Config{ccname} eq 'cl')
-  {
-    $cflags .= " -DFFI_BUILDING";
-  }  
-  
-  $cflags;
-}
+our $VERSION = '0.16'; # VERSION
 
 
 1;
@@ -59,7 +23,7 @@ Alien::FFI - Build and make available libffi
 
 =head1 VERSION
 
-version 0.14
+version 0.16
 
 =head1 SYNOPSIS
 
